@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from deepdiff.helper import items, RemapDict, strings, short_repr, Verbose, notpresent
+from deepdiff.helper import RemapDict, strings, short_repr, Verbose, notpresent
 from ast import literal_eval
 from copy import copy
+from ordered_set import OrderedSet
 
 FORCE_DEFAULT = 'fake'
 UP_DOWN = {'up': 'down', 'down': 'up'}
@@ -33,16 +32,25 @@ class ResultDict(RemapDict):
         Remove empty keys from this object. Should always be called after the result is final.
         :return:
         """
-        empty_keys = [k for k, v in getattr(self, items)() if not v]
+        empty_keys = [k for k, v in self.items() if not v]
 
         for k in empty_keys:
             del self[k]
 
 
+class PrettyOrderedSet(OrderedSet):
+    """
+    From the perspective of the users of the library, they are dealing with lists.
+    Behind the scene, we have ordered sets.
+    """
+    def __repr__(self):
+        return '[{}]'.format(", ".join(map(str, self)))
+
+
 class TreeResult(ResultDict):
     def __init__(self):
         for key in REPORT_KEYS:
-            self[key] = set()
+            self[key] = PrettyOrderedSet()
 
 
 class TextResult(ResultDict):
@@ -59,8 +67,8 @@ class TextResult(ResultDict):
             "iterable_item_removed": {},
             "attribute_added": self.__set_or_dict(),
             "attribute_removed": self.__set_or_dict(),
-            "set_item_removed": set(),
-            "set_item_added": set(),
+            "set_item_removed": PrettyOrderedSet(),
+            "set_item_added": PrettyOrderedSet(),
             "repetition_change": {}
         })
 
@@ -68,7 +76,7 @@ class TextResult(ResultDict):
             self._from_tree_results(tree_results)
 
     def __set_or_dict(self):
-        return {} if Verbose.level >= 2 else set()
+        return {} if Verbose.level >= 2 else PrettyOrderedSet()
 
     def _from_tree_results(self, tree):
         """
@@ -102,7 +110,7 @@ class TextResult(ResultDict):
 
                 # do the reporting
                 report = self[report_type]
-                if isinstance(report, set):
+                if isinstance(report, PrettyOrderedSet):
                     report.add(change.path(force=FORCE_DEFAULT))
                 elif isinstance(report, dict):
                     report[change.path(force=FORCE_DEFAULT)] = item
@@ -117,13 +125,21 @@ class TextResult(ResultDict):
     def _from_tree_type_changes(self, tree):
         if 'type_changes' in tree:
             for change in tree['type_changes']:
+                if type(change.t1) is type:
+                    include_values = False
+                    old_type = change.t1
+                    new_type = change.t2
+                else:
+                    include_values = True
+                    old_type = type(change.t1)
+                    new_type = type(change.t2)
                 remap_dict = RemapDict({
-                    'old_type': type(change.t1),
-                    'new_type': type(change.t2)
+                    'old_type': old_type,
+                    'new_type': new_type
                 })
                 self['type_changes'][change.path(
                     force=FORCE_DEFAULT)] = remap_dict
-                if Verbose.level:
+                if Verbose.level and include_values:
                     remap_dict.update(old_value=change.t1, new_value=change.t2)
 
     def _from_tree_value_changed(self, tree):
@@ -138,7 +154,7 @@ class TextResult(ResultDict):
     def _from_tree_unprocessed(self, tree):
         if 'unprocessed' in tree:
             for change in tree['unprocessed']:
-                self['unprocessed'].append("%s: %s and %s" % (change.path(
+                self['unprocessed'].append("{}: {} and {}".format(change.path(
                     force=FORCE_DEFAULT), change.t1, change.t2))
 
     def _from_tree_set_item_removed(self, tree):
@@ -149,7 +165,7 @@ class TextResult(ResultDict):
                 item = change.t1
                 if isinstance(item, strings):
                     item = "'%s'" % item
-                self['set_item_removed'].add("%s[%s]" % (path, str(item)))
+                self['set_item_removed'].add("{}[{}]".format(path, str(item)))
                 # this syntax is rather peculiar, but it's DeepDiff 2.x compatible
 
     def _from_tree_set_item_added(self, tree):
@@ -160,7 +176,7 @@ class TextResult(ResultDict):
                 item = change.t2
                 if isinstance(item, strings):
                     item = "'%s'" % item
-                self['set_item_added'].add("%s[%s]" % (path, str(item)))
+                self['set_item_added'].add("{}[{}]".format(path, str(item)))
                 # this syntax is rather peculiar, but it's DeepDiff 2.x compatible)
 
     def _from_tree_repetition_change(self, tree):
@@ -172,7 +188,7 @@ class TextResult(ResultDict):
                 self['repetition_change'][path]['value'] = change.t1
 
 
-class DiffLevel(object):
+class DiffLevel:
     """
     An object of this class represents a single object-tree-level in a reported change.
     A double-linked list of these object describes a single change on all of its levels.
@@ -505,7 +521,7 @@ class DiffLevel(object):
         return result
 
 
-class ChildRelationship(object):
+class ChildRelationship:
     """
     Describes the relationship between a container object (the "parent") and the contained
     "child" object.
